import logging

from fastapi import FastAPI
from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession, async_sessionmaker

from fastfood_two.app.depends.session import (
    create_engine,
    create_session_maker,
    get_session,
)
from fastfood_two.common.logger import configure_logger

logger = logging.getLogger(__name__)
configure_logger(level=logging.INFO)


def init_dependencies(app: FastAPI) -> None:
    """Initialize FastAPI dependencies."""

    # app.dependency_overrides[Settings] = get_settings

    app.dependency_overrides[AsyncEngine] = create_engine
    app.dependency_overrides[async_sessionmaker[AsyncSession]] = create_session_maker
    app.dependency_overrides[AsyncSession] = get_session

    logger.info("Dependencies initialized")
